@@ -444,9 +444,8 @@ class GroupStudent(Base):
 
 class Controll(Base):
     """
-    Модель "Контроль"
+    Контроль
     """
-
     __tablename__ = 'univer_control'
 
     # Идентификатор
@@ -457,6 +456,22 @@ class Controll(Base):
     name_kz = Column('control_name_kz', String(100))
     name_en = Column('control_name_en', String(100))
 
+    # Короткое наименование
+    short_name_ru = Column('control_name_ru', String)
+    short_name_kz = Column('control_name_kz', String)
+    short_name_en = Column('control_name_en', String)
+
+    # Максимальная оценка
+    max_ball = Column('control_max_ball', Integer)
+
+    # Статус
+    status = Column(Integer)
+
+    title = Column('control_title', String)
+    has_sheet = Column('control_has_sheet', Integer)
+    date_for_control_id = Column(Integer)
+    is_exam = Column(Integer)
+
     def __repr__(self):
         return '<Controll {} (id={})>'.format(self, self.id)
 
@@ -489,9 +504,7 @@ class ControllType(Base):
 class ControllTypeControllLink(Base):
     """
     Модель "Связь между Controll и ControllType
-    Статус: Выполняется
     """
-
     __tablename__ = 'univer_controll_type_control_link'
 
     # Тип контроля
@@ -509,6 +522,17 @@ class ControllTypeControllLink(Base):
         'univer_sheet_type.sheet_type_id'), primary_key=True)
     sheet_type = relationship('SheetType')
 
+    # Номер контроля
+    control_number = Column(Integer)
+
+    # Минимальный балл
+    control_min_ball = Column(Integer)
+
+    # Порция
+    control_portion = Column(Float)
+
+    retake = Column(Integer)
+
     def __repr__(self):
         return '<ControllTypeControllLink {} (controll_type_id={} controll_id={} sheet_type_id={}>'.format(self, self.controll_type_id, self.controll_id, self.sheet_type_id)
 
